@@ -17,6 +17,7 @@ OC.L10N.register(
     "Restore" : "ফিরিয়ে দাও",
     "Share link" : "লিংক ভাগাভাগি করেন",
     "can edit" : "সম্পাদনা করতে পারবেন",
+    "Save" : "সংরক্ষণ",
     "Cancel" : "বাতিল",
     "Automatic" : "স্বয়ংক্রিয়",
     "Actions" : "পদক্ষেপসমূহ",
@@ -31,7 +32,6 @@ OC.L10N.register(
     "Friday" : "শুক্রবার",
     "Saturday" : "শনিবার",
     "Sunday" : "রবিবার",
-    "Save" : "সংরক্ষণ",
     "Update" : "পরিবর্ধন",
     "Your email address" : "আপনার ই-মেইল ঠিকানা",
     "Notification" : "নোটিফিকেশন ",
@@ -42,13 +42,13 @@ OC.L10N.register(
     "Repeat" : "পূনঃসংঘটন",
     "never" : "কখনোই নয়",
     "More" : "বেশী",
+    "Subscribe" : "গ্রাহক হোন",
     "Personal" : "ব্যক্তিগত",
     "Details" : "বিসতারিত",
     "Attendees" : "অংশগ্রহণকারীবৃন্দ",
     "Close" : "বন্ধ",
     "Daily" : "দৈনিক",
     "Weekly" : "সাপ্তাহিক",
-    "Next" : "পরবর্তী",
     "Other" : "অন্যান্য",
     "Mail" : "মেইল",
     "Birthday" : "জন্মদিন"
