@@ -17,6 +17,7 @@ OC.L10N.register(
     "Delete permanently" : "លុប​ជា​អចិន្ត្រៃយ៍",
     "Share link" : "Share link",
     "can edit" : "អាច​កែប្រែ",
+    "Save" : "រក្សាទុក",
     "Cancel" : "បោះបង់",
     "Location" : "ទីតាំង",
     "Description" : "ការ​អធិប្បាយ",
@@ -29,7 +30,6 @@ OC.L10N.register(
     "Friday" : "ថ្ងៃសុក្រ",
     "Saturday" : "ថ្ងៃសៅរ៍",
     "Sunday" : "ថ្ងៃអាទិត្យ",
-    "Save" : "រក្សាទុក",
     "Update" : "ធ្វើ​បច្ចុប្បន្នភាព",
     "Your email address" : "អ៊ីម៉ែល​របស់​អ្នក",
     "Email" : "អ៊ីមែល",
@@ -45,8 +45,6 @@ OC.L10N.register(
     "Close" : "បិទ",
     "Daily" : "រាល់ថ្ងៃ",
     "Weekly" : "រាល់​សប្ដាហ៍",
-    "Next" : "បន្ទាប់",
-    "Year" : "ឆ្នាំ",
     "Other" : "ផ្សេងៗ",
     "Mail" : "សំបុត្រ",
     "Birthday" : "ថ្ងៃ​កំណើត"
