@@ -6,8 +6,8 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Mēs jūs vēlējāmies informēt, ka %s publicēja kalendāru »%s«.",
     "Open »%s«" : "Atvērt »%s«",
     "Cheers!" : "Priekā!",
-    "Confirm" : "Apstiprināt",
     "Calendar" : "Kalendārs",
+    "Confirm" : "Apstiprināt",
     "A Calendar app for Nextcloud" : "Kalendāra lietotne priekš Nextcloud",
     "New event" : "Jauns notikums",
     "Today" : "Šodien",
@@ -31,6 +31,7 @@ OC.L10N.register(
     "can edit" : "var rediģēt",
     "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
     "No users or groups" : "Nav lietotāji vai grupas",
+    "Save" : "Saglabāt",
     "Filename" : "Datnes nosaukums",
     "Cancel" : "Atcelt",
     "Automatic" : "Automātisks",
@@ -51,11 +52,12 @@ OC.L10N.register(
     "Friday" : "Piektdiena",
     "Saturday" : "Sestdiena",
     "Sunday" : "Svētdiena",
-    "Save" : "Saglabāt",
     "Update" : "Atjaunināt",
     "Your email address" : "Jūsu e-pasta adrese",
     "Notification" : "Paziņojums",
     "Email" : "E-pasts",
+    "Delete file" : "Dzēst datni",
+    "Choose a file to add as attachment" : "Izvēlēties datni ko pievienot kā pielikumu",
     "Available" : "Pieejams",
     "Busy" : "Aizņemts",
     "Unknown" : "Nezināms",
@@ -70,6 +72,7 @@ OC.L10N.register(
     "available" : "pieejams",
     "More" : "Vairāk",
     "Global" : "Globāls",
+    "Subscribe" : "Abonēt",
     "Personal" : "Personīgs",
     "Create a new event" : "Izveidot jaunu notikumu",
     "Details" : "Detaļas",
@@ -80,7 +83,6 @@ OC.L10N.register(
     "Week {number} of {year}" : "{number} nedēļa no {year}",
     "Daily" : "Katru dienu",
     "Weekly" : "Katru nedēļu",
-    "Next" : "Nākamā",
     "Other" : "Cits",
     "When shared show full event" : "Ja koplietots, tad rādīt pilnu notikumu",
     "When shared show only busy" : "Ja koplietots, tad rādīt tikai aizņemts",
