@@ -11,6 +11,7 @@ OC.L10N.register(
     "Open »%s«" : "Accesează »%s«",
     "Cheers!" : "Noroc!",
     "Upcoming events" : "Evenimente viitoare",
+    "Calendar" : "Calendar",
     "Appointments" : "Întâlniri",
     "Schedule appointment \"%s\"" : "Planifică programarea \"%s\"",
     "Schedule an appointment" : "Planifică o programare",
@@ -21,7 +22,6 @@ OC.L10N.register(
     "This confirmation link expires in %s hours." : "Acest link de confirmare expira în %s ore. ",
     "Date:" : "Data:",
     "Where:" : "Unde:",
-    "Calendar" : "Calendar",
     "A Calendar app for Nextcloud" : "O aplicație de tip calendar pentru Nextcloud",
     "Previous day" : "Ziua anterioară",
     "Previous week" : "Săptămâna anterioară",
@@ -72,6 +72,7 @@ OC.L10N.register(
     "Could not restore calendar or event" : "Nu s-a putut restaura calendarul sau evenimentul",
     "Do you really want to empty the trash bin?" : "Doriti sigur sa goliți conținutul coșului de gunoi ?",
     "Could not update calendar order." : "Nu s-a putut actualiza ordinea calendarului.",
+    "Copy internal link" : "Copiază linkul intern",
     "Share link" : "Partajază legătură",
     "Copy public link" : "Copiză link-ul public",
     "Send link to calendar via email" : "Trimite link-ul către calendar folosind email",
@@ -90,12 +91,11 @@ OC.L10N.register(
     "Unpublishing calendar failed" : "Retragerea calendarului a eşuat",
     "can edit" : "poate edita",
     "Unshare with {displayName}" : "Retrage cu {displayName}",
-    "An error occurred, unable to change the unshare the calendar." : "A apărut o eroare, nu se poate schimba retragerea calendarului.",
     "An error occurred, unable to change the permission of the share." : "A apărut o eroare, nu se poate schimba permisiunile fişierelor partajate.",
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
     "No users or groups" : "Nu sunt utilizatori sau grupuri",
-    "Copy private link" : "Copiază link privat",
     "Unshare from me" : "Anulare partajarea cu mine",
+    "Save" : "Salvează",
     "Import calendars" : "Importă calendare",
     "Please select a calendar to import into …" : "Vă rugăm să selectaţi un calendar în care să importaţi ...",
     "Filename" : "Nume fișier",
@@ -124,7 +124,6 @@ OC.L10N.register(
     "Enable birthday calendar" : "Activează calendarul cu zile de naştere",
     "Show tasks in calendar" : "Arată sarcinile în calendar",
     "Enable simplified editor" : "Activează editorul simplificat",
-    "Limit visible events per view" : "Limitează evenimentele vizibile în fiecare mod de vizualizare",
     "Show weekends" : "Arată weekend-uri",
     "Show week numbers" : "Afișați numerele săptămânilor",
     "Time increments" : "Incremente de timp",
@@ -175,7 +174,6 @@ OC.L10N.register(
     "Limit how far in the future appointments can be booked" : "Limitează cât timp în viitor programările pot fi create",
     "Create appointment" : "Creează programare",
     "Edit appointment" : "Editează programarea",
-    "Save" : "Salvează",
     "Update" : "Actualizare",
     "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ți-am trimis un email cu detalii. Te rugăm să confirmi programarea ta folosind linkul din email. Poți închide această pagină acum.",
     "Your name" : "Numele tău",
@@ -203,6 +201,7 @@ OC.L10N.register(
     "_hour_::_hours_" : ["oră","ore","ore"],
     "_day_::_days_" : ["zi","zile","zile"],
     "_week_::_weeks_" : ["săptămână","săptămâni","săptămâni"],
+    "Delete file" : "Șterge fișier",
     "Available" : "Disponibil",
     "Not available" : "Nu este disponibil",
     "Availability of attendees, resources and rooms" : "Disponibilitatea participanților, resurse și camere",
@@ -273,6 +272,7 @@ OC.L10N.register(
     "Pick a time" : "Alege un interval orar",
     "Pick a date" : "Alege o dată",
     "Global" : "Global",
+    "Subscribe" : "Abonare",
     "Time:" : "Timp:",
     "Booked for:" : "Rezervat pentru:",
     "Personal" : "Personal",
@@ -311,11 +311,6 @@ OC.L10N.register(
     "Untitled event" : "Eveniment fără titlu",
     "Untitled task" : "Sarcină fără titlu",
     "Please ask your administrator to enable the Tasks App." : "Vă rugăm să întrebați administratorul dmneavoastră să pornească aplicația Task.",
-    "Prev" : "Precedent",
-    "Next" : "Următorul",
-    "Prev year" : "Anul anterior",
-    "Next year" : "Aanul viitor",
-    "Year" : "An",
     "W" : "W",
     "%n more" : "%n mai mult",
     "No events to display" : "Nu sunt evenimente de afișat",
