@@ -24,8 +24,8 @@ declare(strict_types=1);
 namespace OCA\Calendar\Controller;
 
 use OCP\AppFramework\Controller;
-use OCP\AppFramework\Http\JSONResponse;
 use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\JSONResponse;
 use OCP\IConfig;
 use OCP\IRequest;
 
@@ -35,7 +35,6 @@ use OCP\IRequest;
  * @package OCA\Calendar\Controller
  */
 class SettingsController extends Controller {
-
 	/** @var IConfig */
 	private $config;
 
@@ -51,9 +50,9 @@ class SettingsController extends Controller {
 	 * @param string $userId
 	 */
 	public function __construct(string $appName,
-								IRequest $request,
-								IConfig $config,
-								string $userId) {
+		IRequest $request,
+		IConfig $config,
+		string $userId) {
 		parent::__construct($appName, $request);
 		$this->config = $config;
 		$this->userId = $userId;
@@ -69,7 +68,7 @@ class SettingsController extends Controller {
 	 * @return JSONResponse
 	 */
 	public function setConfig(string $key,
-							  string $value):JSONResponse {
+		string $value):JSONResponse {
 		switch ($key) {
 			case 'view':
 				return $this->setView($value);
@@ -91,6 +90,8 @@ class SettingsController extends Controller {
 				return $this->setDefaultReminder($value);
 			case 'showTasks':
 				return $this->setShowTasks($value);
+			case 'attachmentsFolder':
+				return $this->setAttachmentsFolder($value);
 			default:
 				return new JSONResponse([], Http::STATUS_BAD_REQUEST);
 		}
@@ -172,6 +173,27 @@ class SettingsController extends Controller {
 		return new JSONResponse();
 	}
 
+	/**
+	 * Set config for attachments folder
+	 *
+	 * @param string $value
+	 * @return JSONResponse
+	 */
+	private function setAttachmentsFolder(string $value):JSONResponse {
+		try {
+			$this->config->setUserValue(
+				$this->userId,
+				'dav',
+				'attachmentsFolder',
+				$value
+			);
+		} catch (\Exception $e) {
+			return new JSONResponse([], Http::STATUS_INTERNAL_SERVER_ERROR);
+		}
+
+		return new JSONResponse();
+	}
+
 	/**
 	 * set config value for showing week numbers
 	 *
