@@ -41,7 +41,6 @@ use Sabre\VObject\Component\VCalendar;
 use function abs;
 
 class BookingCalendarWriter {
-
 	/** @var IConfig */
 	private $config;
 
@@ -57,10 +56,10 @@ class BookingCalendarWriter {
 	private $l10n;
 
 	public function __construct(IConfig $config,
-								IManager $manager,
-								IUserManager $userManager,
-								ISecureRandom $random,
-								IL10N $l10n) {
+		IManager $manager,
+		IUserManager $userManager,
+		ISecureRandom $random,
+		IL10N $l10n) {
 		$this->config = $config;
 		$this->manager = $manager;
 		$this->userManager = $userManager;
@@ -109,7 +108,8 @@ class BookingCalendarWriter {
 			'CALSCALE' => 'GREGORIAN',
 			'VERSION' => '2.0',
 			'VEVENT' => [
-				'SUMMARY' => $config->getName(),
+				// TRANSLATORS Title for event appoinment, first the attendee name, then the appointment name
+				'SUMMARY' => $this->l10n->t('%1$s - %2$s', [$displayName, $config->getName()]),
 				'STATUS' => 'CONFIRMED',
 				'DTSTART' => $start,
 				'DTEND' => $start->setTimestamp($start->getTimestamp() + ($config->getLength()))
